@@ -7,7 +7,8 @@ import abc
 class BaseEnvironment(abc.ABC):
     """Interface for environments."""
     def display(self, html):
-        pass
+        from IPython.display import HTML, display
+        display(HTML(html), metadata=dict(isolated=True))
 
     def select(self, service):
         pass
